summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorBharat Raghunathan <bharatraghunthan9767@gmail.com>2021-05-23 19:28:38 +0530
committerGitHub <noreply@github.com>2021-05-23 06:58:38 -0700
commit7ebd9f94a8e9ca8e3f08b93cfdb46103b8925cd1 (patch)
tree8161fafc58562d9a0c8055b6b886b7935fba6c61
parente7a38bdc2874ec697ec28fc048a4d3204190c002 (diff)
downloadnetworkx-7ebd9f94a8e9ca8e3f08b93cfdb46103b8925cd1.tar.gz
DOC: Clarify behaviour of k_crust(G, k) (#4831)
-rw-r--r--networkx/algorithms/core.py3
1 files changed, 2 insertions, 1 deletions
diff --git a/networkx/algorithms/core.py b/networkx/algorithms/core.py
index f95ba792..82be5cb9 100644
--- a/networkx/algorithms/core.py
+++ b/networkx/algorithms/core.py
@@ -259,7 +259,8 @@ def k_shell(G, k=None, core_number=None):
def k_crust(G, k=None, core_number=None):
"""Returns the k-crust of G.
- The k-crust is the graph G with the k-core removed.
+ The k-crust is the graph G with the edges of the k-core removed
+ and isolated nodes found after the removal of edges are also removed.
Parameters
----------